@@ -66,7 +66,6 @@ import psutil
 from oslo_concurrency import lockutils
 from nova.compute import task_states
 from oslo_utils import excutils
-from oslo_utils import strutils
 from nova.virt import firewall
 
 _ = i18n._
@@ -124,9 +123,9 @@ def _last_bytes(file_like_object, num):
 
 
 def _neutron_failed_callback(event_name, instance):
-    LOG.error('Neutron Reported failure on event '
-              '%(event)s for instance %(uuid)s',
-              {'event': event_name, 'uuid': instance.name},
+    LOG.error("Neutron Reported failure on event "
+              "{event} for instance {uuid}"
+              .format(event=event_name, uuid=instance.name),
               instance=instance)
     if CONF.vif_plugging_is_fatal:
         raise exception.VirtualInterfaceCreateException()
@@ -141,7 +140,7 @@ def _get_cpu_info():
     cpuinfo = {}
     out, err = utils.execute('lscpu')
     if err:
-        msg = _('Unable to parse lscpu output.')
+        msg = _("Unable to parse lscpu output.")
         raise exception.NovaException(msg)
 
     cpu = [line.strip('\n') for line in out.splitlines()]
@@ -192,23 +191,43 @@ def _get_fs_info(path):
             'used': used}
 
 
-def _get_zpool_info(pool):
-    """Get free/used/total disk space in a zfs pool."""
-    def _get_zpool_attribute(attribute):
-        value, err = utils.execute('zpool', 'list',
+def _get_zpool_info(pool_or_dataset):
+    """Get the free/used/total diskspace in a zfs pool or dataset.
+    A dataset is distinguished by having a '/' in the string.
+
+    :param pool_or_dataset: The string name of the pool or dataset
+    :type pool_or_dataset: str
+    :returns: dictionary with keys 'total', 'available', 'used'
+    :rtype: Dict[str, int]
+    :raises: :class:`exception.NovaException`
+    :raises: :class:`oslo.concurrency.PorcessExecutionError`
+    :raises: :class:`OSError`
+    """
+    def _get_zfs_attribute(cmd, attribute):
+        value, err = utils.execute(cmd, 'list',
                                    '-o', attribute,
-                                   '-H', pool,
+                                   '-H',
+                                   '-p',
+                                   pool_or_dataset,
                                    run_as_root=True)
         if err:
-            msg = _('Unable to parse zpool output.')
+            msg = _("Unable to parse zfs output.")
             raise exception.NovaException(msg)
-        value = strutils.string_to_bytes('{}B'.format(value.strip()),
-                                         return_int=True)
+        value = int(value.strip())
         return value
 
-    total = _get_zpool_attribute('size')
-    used = _get_zpool_attribute('alloc')
-    available = _get_zpool_attribute('free')
+    if '/' in pool_or_dataset:
+        # it's a dataset:
+        # for zfs datasets we only have 'available' and 'used' and so need to
+        # construct the total from available and used.
+        used = _get_zfs_attribute('zfs', 'used')
+        available = _get_zfs_attribute('zfs', 'available')
+        total = available + used
+    else:
+        # otherwise it's a zpool
+        total = _get_zfs_attribute('zpool', 'size')
+        used = _get_zfs_attribute('zpool', 'alloc')
+        available = _get_zfs_attribute('zpool', 'free')
     return {'total': total,
             'available': available,
             'used': used}
@@ -255,13 +274,13 @@ def _sync_glance_image_to_lxd(client, context, image_ref):
                 raise
 
         try:
-            image_file = tempfile.mkstemp()[1]
-            manifest_file = tempfile.mkstemp()[1]
+            ifd, image_file = tempfile.mkstemp()
+            mfd, manifest_file = tempfile.mkstemp()
 
             image = IMAGE_API.get(context, image_ref)
             if image.get('disk_format') not in ACCEPTABLE_IMAGE_FORMATS:
                 raise exception.ImageUnacceptable(
-                    image_id=image_ref, reason=_('Bad image format'))
+                    image_id=image_ref, reason=_("Bad image format"))
             IMAGE_API.download(context, image_ref, dest_path=image_file)
 
             # It is possible that LXD already have the same image
@@ -288,10 +307,10 @@ def _sync_glance_image_to_lxd(client, context, image_ref):
 
                 fingerprint = lxdimage_fingerprint()
                 if client.images.exists(fingerprint):
-                    LOG.info(
-                        'Image with fingerprint %(fingerprint)s already exists'
-                        'but not accessible by alias %(alias)s, add alias',
-                        {'fingerprint': fingerprint, 'alias': image_ref})
+                    LOG.info("Image with fingerprint {fingerprint} already "
+                             "exists but not accessible by alias {alias}, "
+                             "add alias"
+                             .format(fingerprint=fingerprint, alias=image_ref))
                     lxdimage = client.images.get(fingerprint)
                     lxdimage.add_alias(image_ref, '')
                     return True
@@ -322,9 +341,9 @@ def _sync_glance_image_to_lxd(client, context, image_ref):
                 return False
 
             if imagefile_has_metadata(image_file):
-                LOG.info('Image %(alias)s already has metadata, '
-                         'skipping metadata injection...',
-                         {'alias': image_ref})
+                LOG.info("Image {alias} already has metadata, "
+                         "skipping metadata injection..."
+                         .format(alias=image_ref))
                 with open(image_file, 'rb') as image:
                     image = client.images.create(image, wait=True)
             else:
@@ -353,6 +372,8 @@ def _sync_glance_image_to_lxd(client, context, image_ref):
             image.add_alias(image_ref, '')
 
         finally:
+            os.close(ifd)
+            os.close(mfd)
             os.unlink(image_file)
             os.unlink(manifest_file)
 
@@ -443,7 +464,7 @@ class LXDDriver(driver.ComputeDriver):
         try:
             self.client = pylxd.Client()
         except lxd_exceptions.ClientConnectionFailed as e:
-            msg = _('Unable to connect to LXD daemon: %s') % e
+            msg = _("Unable to connect to LXD daemon: {}").format(e)
             raise exception.HostNotFound(msg)
         self._after_reboot()
 
@@ -524,8 +545,9 @@ class LXDDriver(driver.ComputeDriver):
                         error_callback=_neutron_failed_callback):
                     self.plug_vifs(instance, network_info)
             except eventlet.timeout.Timeout:
-                LOG.warn('Timeout waiting for vif plugging callback for '
-                         'instance %(uuid)s', {'uuid': instance['name']})
+                LOG.warn("Timeout waiting for vif plugging callback for "
+                         "instance {uuid}"
+                         .format(uuid=instance['name']))
                 if CONF.vif_plugging_is_fatal:
                     self.destroy(
                         context, instance, network_info, block_device_info)
@@ -618,9 +640,9 @@ class LXDDriver(driver.ComputeDriver):
                 rescued_container.delete(wait=True)
         except lxd_exceptions.LXDAPIException as e:
             if e.response.status_code == 404:
-                LOG.warning('Failed to delete instance. '
-                            'Container does not exist for %(instance)s.',
-                            {'instance': instance.name})
+                LOG.warning("Failed to delete instance. "
+                            "Container does not exist for {instance}."
+                            .format(instance=instance.name))
             else:
                 raise
         finally:
@@ -657,9 +679,9 @@ class LXDDriver(driver.ComputeDriver):
             self.client.profiles.get(instance.name).delete()
         except lxd_exceptions.LXDAPIException as e:
             if e.response.status_code == 404:
-                LOG.warning('Failed to delete instance. '
-                            'Profile does not exist for %(instance)s.',
-                            {'instance': instance.name})
+                LOG.warning("Failed to delete instance. "
+                            "Profile does not exist for {instance}."
+                            .format(instance=instance.name))
             else:
                 raise
 
@@ -737,7 +759,7 @@ class LXDDriver(driver.ComputeDriver):
         profile.config.update({'raw.apparmor': 'mount fstype=ext4,'})
         profile.save()
 
-    def detach_volume(self, connection_info, instance, mountpoint,
+    def detach_volume(self, context, connection_info, instance, mountpoint,
                       encryption=None):
         """Detach block device from a nova instance.
 
@@ -1190,7 +1212,7 @@ class LXDDriver(driver.ComputeDriver):
     def check_can_live_migrate_source(self, context, instance,
                                       dest_check_data, block_device_info=None):
         if not CONF.lxd.allow_live_migration:
-            msg = _('Live migration is not enabled.')
+            msg = _("Live migration is not enabled.")
             LOG.error(msg, instance=instance)
             raise exception.MigrationPreCheckError(reason=msg)
         return dest_check_data
@@ -1262,9 +1284,8 @@ class LXDDriver(driver.ComputeDriver):
                 cdb.make_drive(iso_path)
             except processutils.ProcessExecutionError as e:
                 with excutils.save_and_reraise_exception():
-                    LOG.error('Creating config drive failed with '
-                              'error: %s',
-                              e, instance=instance)
+                    LOG.error("Creating config drive failed with error: {}"
+                              .format(e), instance=instance)
 
         configdrive_dir = os.path.join(
             nova.conf.CONF.instances_path, instance.name, 'configdrive')
